@@ -6,7 +6,7 @@ package OAuthomatic;
 
 
 use Moose;
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.0201'; # VERSION
 use namespace::sweep;
 # FIXME: switch to Moo
 use MooseX::AttributeShortcuts;
@@ -36,8 +36,6 @@ const my @_CONFIG_ATTRIBUTES => (
     'html_dir', 'debug',
    );
 
-# FIXME: sample below can be bad
-
 
 has 'config' => (
     is => 'ro', isa => 'OAuthomatic::Config', required => 1,
@@ -336,8 +334,6 @@ sub ensure_authorized {
     return;
 }
 
-# FIXME: invalidate saved tokens when they are cancelled on the website
-
 ######################################################################
 # Making requests
 ######################################################################
@@ -447,7 +443,6 @@ sub post_xml {
         push @args, (url_args => shift);
     }
     my $body = shift;
-    # FIXME: encode if unicode?
     push @args, (body => $body);
 
     my $r = $self->execute_request(@args);
@@ -549,7 +544,7 @@ OAuthomatic - automate setup of access to OAuth-secured resources. Intended espe
 
 =head1 VERSION
 
-version 0.02
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -920,9 +915,8 @@ parameters.
 
 Note: if you are executing requests yourself, consider detecting cases
 of wrong client credentials, obsolete token credentials etc, and
-calling or L</erase_client_cred> or L</erase_token_cred>.
-
-FIXME: description how to check.
+calling or L</erase_client_cred> or L</erase_token_cred>. 
+The L<OAuthomatic::Error::HTTPFailure> may be of help.
 
 =head2 get
 
@@ -1175,6 +1169,34 @@ parts of my module.
 
 E. Hammer-Lahav for well written and understandable RFC 5849.
 
+=head1 SOURCE REPOSITORY
+
+Source code is maintained in L<Mercurial|http://mercurial.selenic.com>
+repository at L<bitbucket.org/Mekk/perl-oauthomatic|https://bitbucket.org/Mekk/perl-oauthomatic>:
+
+    hg clone https://bitbucket.org/Mekk/perl-oauthomatic
+
+See C<README-development.pod> in source distribution for info how to
+build module from source.
+
+=head1 ISSUE TRACKER
+
+Issues can be reported at:
+
+=over
+
+=item *
+
+L<Bitbucket issue tracker|https://bitbucket.org/Mekk/perl-oauthomatic/issues>
+
+=item *
+
+L<CPAN bug tracker|https://rt.cpan.org/Dist/Display.html?Queue=OAuthomatic>
+
+=back
+
+The former is slightly preferred but feel free using CPAN tracker if you find it more usable.
+
 =head1 AUTHOR
 
 Marcin Kasperski <Marcin.Kasperski@mekk.waw.pl>
