@@ -11,21 +11,28 @@ Types below are defined to make code a bit more readable and less error prone.
 
 =cut
 
-=head1 OAuthomatic::Types::StructCleaner
+=head1 OAuthomatic::Types::StructBase
 
-Role composed into types defined below. Handles some construction
+Role composed into types defined below. Handles a few common
 conventions.
 
+=head2 METHODS
+
+=head3 new
+
+Adds two conventions to usual parameter handling:
+
 =over 4
 
 =item *
 
-Any empty or undef'ed values are dropped as if they were not specified at all.
+Any empty or undef'ed values given to the constructor are dropped as
+if they were not specified at all.
 
 =item *
 
-If args C<data> and C<remap> are given, constructor can translate
-field names, for example:
+If args C<data> and C<remap> are given to the constructor, they are
+used to translate field names, for example:
 
     Something->new(data=>{aaa=>'x', bbb=>'y'},
                    remap=>{aaa=>'token', 'bbb'=>'secret');
@@ -39,15 +46,24 @@ Partial replacements are possible too:
     Something->new(data=>{token=>'x', bbb=>'y'},
                    remap=>{'bbb'=>'secret');
 
-
 =back
 
+=head3 Class->of_my_type(obj)
+
+Checks whether given object is of given structure type. Returns 1 if so, 0 if it is undef,
+throws if it is of another type.
+
+=head2 Class->equal(obj1, obj2)
+
+Compares two objects, allowing undef-s but raises on wrong type.
+
 =cut
 
 {
-    package OAuthomatic::Types::StructCleaner;
+    package OAuthomatic::Types::StructBase;
     use Moose::Role;
     use OAuthomatic::Error;
+    use Scalar::Util qw(blessed);
     use namespace::sweep;
 
     around BUILDARGS => sub {
@@ -88,6 +104,19 @@ Partial replacements are possible too:
             }
         }
         return $ret;
+    };
+
+    sub of_my_type {
+        my ($class, $obj) = @_;
+        return '' if ! defined($obj);
+        my $pkg = blessed($obj);
+        unless( $pkg ) {
+            OAuthomatic::Error::Generic->throw(
+                ident => "Bad parameter", extra => "Wrong object type (expected $class, got non-blessed scalar)");
+        }
+        return 1 if $obj->isa($class);
+        return OAuthomatic::Error::Generic->throw(
+            ident => "Bad parameter", extra => "Wrong object type (expected $class, got $pkg)");
     }
 };
 
@@ -117,7 +146,7 @@ is valid.
 {
     package OAuthomatic::Types::ClientCred;
     use Moose;
-    with 'OAuthomatic::Types::StructCleaner';
+    with 'OAuthomatic::Types::StructBase';
 
     has 'key' => (is => 'ro', isa => 'Str', required => 1);
     has 'secret' => (is => 'ro', isa => 'Str', required => 1);
@@ -132,27 +161,19 @@ is valid.
 
     sub equal {
         my ($class, $left, $right) = @_;
-        if(defined($left)) {
-            if(defined($right)) {
-                ($left->isa($class) && $right->isa($class)) or 
-                  OAuthomatic::Error::Generic->throw(
-                      ident => "Bad parameters", extra => "equal called for wrong object types");
-                return ($left->key eq $right->key) 
-                  && ($left->secret eq $right->secret);
-            } else {
-                return '';
-            }
-        } else {
-            return ! defined($right);
-        }
+        # Croaks of mismatches, false on undefs
+        return '' unless $class->of_my_type($left) && $class->of_my_type($right);
+        # Compare all fields
+        return ($left->key eq $right->key) && ($left->secret eq $right->secret);
     }
+
 };
 
 # Common implementation for two classes below
 {
     package OAuthomatic::Types::GenericTokenCred;
     use Moose;
-    with 'OAuthomatic::Types::StructCleaner';
+    with 'OAuthomatic::Types::StructBase';
 
     has 'token' => (is => 'ro', isa => 'Str', required => 1);
     has 'secret' => (is => 'ro', isa => 'Str', required => 1);
@@ -167,19 +188,10 @@ is valid.
 
     sub equal {
         my ($class, $left, $right) = @_;
-        if(defined($left)) {
-            if(defined($right)) {
-                ($left->isa($class) && $right->isa($class)) or 
-                  OAuthomatic::Error::Generic->throw(
-                      ident => "Bad parameters", extra => "equal called for wrong object types");
-                return ($left->token eq $right->token) 
-                  && ($left->secret eq $right->secret);
-            } else {
-                return '';
-            }
-        } else {
-            return ! defined($right);
-        }
+        # Croaks of mismatches, 0 on undefs
+        return '' unless $class->of_my_type($left) && $class->of_my_type($right);
+        # Compare all fields
+        return ($left->token eq $right->token) && ($left->secret eq $right->secret);
     }
 };
 
@@ -240,26 +252,17 @@ Verifier info, returned from authorization.
 {
     package OAuthomatic::Types::Verifier;
     use Moose;
-    with 'OAuthomatic::Types::StructCleaner';
+    with 'OAuthomatic::Types::StructBase';
 
     has 'token' => (is => 'ro', isa => 'Str', required => 1);
     has 'verifier' => (is => 'ro', isa => 'Str', required => 1);
 
     sub equal {
         my ($class, $left, $right) = @_;
-        if(defined($left)) {
-            if(defined($right)) {
-                ($left->isa($class) && $right->isa($class)) or 
-                  OAuthomatic::Error::Generic->throw(
-                      ident => "Bad parameters", extra => "equal called for wrong object types");
-                return ($left->token eq $right->token) 
-                  && ($left->verifier eq $right->verifier);
-            } else {
-                return '';
-            }
-        } else {
-            return ! defined($right);
-        }
+        # Croaks of mismatches, 0 on undefs
+        return '' unless $class->of_my_type($left) && $class->of_my_type($right);
+        # Compare all fields
+        return ($left->token eq $right->token) && ($left->verifier eq $right->verifier);
     }
 };
 
